wellformednesstools.Check
=========================

.. abjad-lineage:: abjad.tools.wellformednesstools.Check.Check.Check

.. autoclass:: abjad.tools.wellformednesstools.Check.Check.Check
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.wellformednesstools.Check.Check.Check.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.check
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.report
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.violators
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__eq__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ge__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__gt__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__le__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__lt__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ne__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__repr__
   :noindex:
